@@ -5,6 +5,7 @@ from typing import Optional, Literal
 from fastapi_camelcase import CamelModel
 from pydantic import Field
 from telus_bulk.models.ams.coordinate import Coordinate
+from telus_bulk.models.clli import Clli
 
 
 class Place(CamelModel):
@@ -32,3 +33,4 @@ class PlaceAMS(Place):
     unit: Optional[str] = None
     address_type: Optional[str] = None
     coordinate: Optional[Coordinate] = None
+    clli: Optional[Clli] = Field(default=None)
